import React from 'react'
import { Redirect, Route, RouteProps } from 'react-router-dom';

import { useGoogleAuth } from 'hooks';

interface CustomRouteProps extends RouteProps {
    component: React.ComponentType;
}
  
export const PublicRoute: React.FC<CustomRouteProps> = ({component: Component, ...rest}) => {
    const { isSignedIn } = useGoogleAuth();

    return (
        <Route {...rest} render={(props: any) => (
            !isSignedIn ?
            <Component {...props} /> : 
            <Redirect exact to="/orders" />
        )} />    
    );
};

export const PrivateRoute: React.FC<CustomRouteProps>  = ({component: Component, ...rest}) => {
    const { isSignedIn } = useGoogleAuth();

    return (
        <Route {...rest} render={(props: any) => (
            isSignedIn ?
            <Component  {...props }/>: 
            <Redirect exact from="/orders" to="/" />
        )} />
    );
};